@@ -37,7 +37,7 @@ impl Emulator {
 			Self::Iterm2 => vec![Adapter::Iterm2, Adapter::Sixel],
 			Self::WezTerm => vec![Adapter::Iterm2, Adapter::Sixel],
 			Self::Foot => vec![Adapter::Sixel],
-			Self::Ghostty => vec![Adapter::KittyOld],
+			Self::Ghostty => vec![Adapter::Kitty],
 			Self::BlackBox => vec![Adapter::Sixel],
 			Self::VSCode => vec![Adapter::Iterm2, Adapter::Sixel],
 			Self::Tabby => vec![Adapter::Iterm2, Adapter::Sixel],
@@ -199,10 +199,10 @@ impl Emulator {
 					bail!("unexpected EOF");
 				}
 				buf.push(c[0]);
-				if c[0] != b'c' || !buf.contains(&b'\x1b') {
+				if c[0] != b'c' || !buf.contains(&0x1b) {
 					continue;
 				}
-				if buf.rsplitn(2, |&b| b == b'\x1b').next().is_some_and(|s| s.starts_with(b"[?")) {
+				if buf.rsplitn(2, |&b| b == 0x1b).next().is_some_and(|s| s.starts_with(b"[?")) {
 					break;
 				}
 			}
