@@ -39,19 +39,33 @@ impl Manager {
 	pub fn active_mut(&mut self) -> &mut Tab { self.tabs.active_mut() }
 
 	#[inline]
-	pub fn current(&self) -> &Folder { &self.tabs.active().current }
+	pub fn active_or(&self, idx: Option<usize>) -> &Tab { self.tabs.active_or(idx) }
 
 	#[inline]
-	pub fn current_mut(&mut self) -> &mut Folder { &mut self.tabs.active_mut().current }
+	pub fn active_or_mut(&mut self, idx: Option<usize>) -> &mut Tab { self.tabs.active_or_mut(idx) }
 
 	#[inline]
-	pub fn parent(&self) -> Option<&Folder> { self.tabs.active().parent.as_ref() }
+	pub fn current(&self) -> &Folder { &self.active().current }
 
 	#[inline]
-	pub fn hovered(&self) -> Option<&File> { self.tabs.active().current.hovered() }
+	pub fn current_mut(&mut self) -> &mut Folder { &mut self.active_mut().current }
 
 	#[inline]
-	pub fn hovered_folder(&self) -> Option<&Folder> { self.tabs.active().hovered_folder() }
+	pub fn current_or(&self, idx: Option<usize>) -> &Folder { &self.active_or(idx).current }
+
+	#[inline]
+	pub fn current_or_mut(&mut self, idx: Option<usize>) -> &mut Folder {
+		&mut self.active_or_mut(idx).current
+	}
+
+	#[inline]
+	pub fn parent(&self) -> Option<&Folder> { self.active().parent.as_ref() }
+
+	#[inline]
+	pub fn hovered(&self) -> Option<&File> { self.active().current.hovered() }
+
+	#[inline]
+	pub fn hovered_folder(&self) -> Option<&Folder> { self.active().hovered_folder() }
 
 	#[inline]
 	pub fn selected_or_hovered(&self, reorder: bool) -> Box<dyn Iterator<Item = &Url> + '_> {
