@@ -1,9 +1,9 @@
-use std::str::FromStr;
+use std::{collections::HashSet, str::FromStr};
 
 use yazi_config::{keymap::{Control, Key}, KEYMAP};
 use yazi_shared::{event::Cmd, render, Layer};
 
-use crate::which::Which;
+use crate::which::{Which, WhichSorter};
 
 pub struct Opt {
 	cands:  Vec<Control>,
@@ -16,9 +16,9 @@ impl TryFrom<Cmd> for Opt {
 
 	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> {
 		Ok(Self {
-			cands:  c.take_data().unwrap_or_default(),
-			layer:  Layer::from_str(&c.take_name("layer").unwrap_or_default())?,
-			silent: c.named.contains_key("silent"),
+			cands:  c.take_any("candidates").unwrap_or_default(),
+			layer:  Layer::from_str(&c.take_str("layer").unwrap_or_default())?,
+			silent: c.bool("silent"),
 		})
 	}
 }
@@ -43,15 +43,19 @@ impl Which {
 	}
 
 	pub fn show_with(&mut self, key: &Key, layer: Layer) {
+		let mut seen = HashSet::new();
+
 		self.layer = layer;
 		self.times = 1;
 		self.cands = KEYMAP
 			.get(layer)
 			.iter()
 			.filter(|c| c.on.len() > 1 && &c.on[0] == key)
+			.filter(|&c| seen.insert(&c.on))
 			.map(|c| c.into())
 			.collect();
 
+		WhichSorter::default().sort(&mut self.cands);
 		self.visible = true;
 		self.silent = false;
 		render!();
