@@ -1,12 +1,11 @@
-use std::sync::atomic::AtomicBool;
-
-use ratatui::{buffer::Buffer, layout::{Constraint, Layout, Rect}, widgets::Widget};
+use mlua::{Table, TableExt};
+use ratatui::{buffer::Buffer, layout::Rect, widgets::Widget};
+use tracing::error;
+use yazi_plugin::{bindings::Cast, elements::render_widgets, LUA};
 
 use super::{completion, input, select, tasks, which};
 use crate::{components, help, Ctx};
 
-pub(super) static COLLISION: AtomicBool = AtomicBool::new(false);
-
 pub(super) struct Root<'a> {
 	cx: &'a Ctx,
 }
@@ -17,13 +16,17 @@ impl<'a> Root<'a> {
 
 impl<'a> Widget for Root<'a> {
 	fn render(self, area: Rect, buf: &mut Buffer) {
-		let chunks =
-			Layout::vertical([Constraint::Length(1), Constraint::Min(0), Constraint::Length(1)])
-				.split(area);
+		let mut f = || {
+			let area = yazi_plugin::elements::Rect::cast(&LUA, area)?;
+			let root = LUA.globals().raw_get::<_, Table>("Root")?.call_method::<_, Table>("new", area)?;
+
+			render_widgets(root.call_method("render", ())?, buf);
+			Ok::<_, mlua::Error>(())
+		};
+		if let Err(e) = f() {
+			error!("Failed to render the `Root` component:\n{e}");
+		}
 
-		components::Header.render(chunks[0], buf);
-		components::Manager.render(chunks[1], buf);
-		components::Status.render(chunks[2], buf);
 		components::Preview::new(self.cx).render(area, buf);
 
 		if self.cx.tasks.visible {
