@@ -1,5 +1,7 @@
-use mlua::{AnyUserData, Lua, Table, UserData, UserDataMethods};
-use yazi_config::theme::Color;
+use std::str::FromStr;
+
+use mlua::{AnyUserData, ExternalError, ExternalResult, Lua, Table, UserData, UserDataMethods, Value};
+use yazi_shared::theme::Color;
 
 #[derive(Clone, Copy, Default)]
 pub struct Style(pub(super) ratatui::style::Style);
@@ -11,26 +13,28 @@ impl Style {
 		let style = lua.create_table()?;
 		style.set_metatable(Some(lua.create_table_from([("__call", new)])?));
 
-		ui.set("Style", style)
+		ui.raw_set("Style", style)
 	}
 }
 
-impl From<yazi_config::theme::Style> for Style {
-	fn from(value: yazi_config::theme::Style) -> Self { Self(value.into()) }
+impl From<yazi_shared::theme::Style> for Style {
+	fn from(value: yazi_shared::theme::Style) -> Self { Self(value.into()) }
 }
 
-impl<'a> From<Table<'a>> for Style {
-	fn from(value: Table) -> Self {
+impl<'a> TryFrom<Table<'a>> for Style {
+	type Error = mlua::Error;
+
+	fn try_from(value: Table<'a>) -> Result<Self, Self::Error> {
 		let mut style = ratatui::style::Style::default();
-		if let Ok(fg) = value.get::<_, String>("fg") {
-			style.fg = Color::try_from(fg).ok().map(Into::into);
+		if let Ok(fg) = value.raw_get::<_, mlua::String>("fg") {
+			style.fg = Some(Color::from_str(fg.to_str()?).into_lua_err()?.into());
 		}
-		if let Ok(bg) = value.get::<_, String>("bg") {
-			style.bg = Color::try_from(bg).ok().map(Into::into);
+		if let Ok(bg) = value.raw_get::<_, mlua::String>("bg") {
+			style.bg = Some(Color::from_str(bg.to_str()?).into_lua_err()?.into());
 		}
 		style.add_modifier =
-			ratatui::style::Modifier::from_bits_truncate(value.get("modifier").unwrap_or_default());
-		Self(style)
+			ratatui::style::Modifier::from_bits_truncate(value.raw_get("modifier").unwrap_or_default());
+		Ok(Self(style))
 	}
 }
 
@@ -68,6 +72,10 @@ impl UserData for Style {
 			ud.borrow_mut::<Self>()?.0.add_modifier |= ratatui::style::Modifier::RAPID_BLINK;
 			Ok(ud)
 		});
+		methods.add_function("reverse", |_, ud: AnyUserData| {
+			ud.borrow_mut::<Self>()?.0.add_modifier |= ratatui::style::Modifier::REVERSED;
+			Ok(ud)
+		});
 		methods.add_function("hidden", |_, ud: AnyUserData| {
 			ud.borrow_mut::<Self>()?.0.add_modifier |= ratatui::style::Modifier::HIDDEN;
 			Ok(ud)
@@ -80,5 +88,16 @@ impl UserData for Style {
 			ud.borrow_mut::<Self>()?.0.add_modifier = ratatui::style::Modifier::empty();
 			Ok(ud)
 		});
+		methods.add_function("patch", |_, (ud, value): (AnyUserData, Value)| {
+			{
+				let mut me = ud.borrow_mut::<Self>()?;
+				me.0 = me.0.patch(match value {
+					Value::Table(tb) => Style::try_from(tb)?.0,
+					Value::UserData(ud) => ud.borrow::<Style>()?.0,
+					_ => return Err("expected a Style or Table".into_lua_err()),
+				});
+			}
+			Ok(ud)
+		})
 	}
 }
