@@ -7,17 +7,18 @@ use yazi_shared::fs::{File, Url};
 pub struct FdOpt {
 	pub cwd:     Url,
 	pub hidden:  bool,
-	pub glob:    bool,
 	pub subject: String,
+	pub args:    Vec<String>,
 }
 
 pub fn fd(opt: FdOpt) -> Result<UnboundedReceiver<File>> {
 	let mut child = Command::new("fd")
 		.arg("--base-directory")
 		.arg(&opt.cwd)
-		.args(if opt.hidden { ["--hidden", "--no-ignore"] } else { ["--no-hidden", "--ignore"] })
-		.arg(if opt.glob { "--glob" } else { "--regex" })
-		.arg(&opt.subject)
+		.arg("--regex")
+		.arg(if opt.hidden { "--hidden" } else { "--no-hidden" })
+		.args(opt.args)
+		.arg(opt.subject)
 		.kill_on_drop(true)
 		.stdout(Stdio::piped())
 		.stderr(Stdio::null())
