@@ -2,9 +2,12 @@
 
 pub mod bindings;
 mod cast;
+pub mod cha;
+mod clipboard;
 mod config;
 pub mod elements;
 pub mod external;
+pub mod file;
 pub mod fs;
 pub mod isolate;
 pub mod loader;
@@ -17,12 +20,16 @@ pub mod url;
 pub mod utils;
 
 pub use cast::*;
+pub use clipboard::*;
 pub use config::*;
 pub use lua::*;
 pub use opt::*;
 pub use runtime::*;
 
-pub fn init() {
+pub fn init() -> anyhow::Result<()> {
+	CLIPBOARD.with(<_>::default);
+
 	crate::loader::init();
-	crate::init_lua();
+	crate::init_lua()?;
+	Ok(())
 }
