@@ -3,7 +3,7 @@ use mlua::{Lua, Table};
 use yazi_config::PREVIEW;
 
 use super::Utils;
-use crate::{bindings::{Cast, FileRef}, url::Url};
+use crate::{bindings::Cast, file::FileRef, url::Url};
 
 impl Utils {
 	pub(super) fn cache(lua: &Lua, ya: &Table) -> mlua::Result<()> {
@@ -17,7 +17,7 @@ impl Utils {
 
 				let hex = {
 					let mut digest = Md5::new_with_prefix(file.url.as_os_str().as_encoded_bytes());
-					digest.update(&format!("//{:?}//{}", file.cha.modified, t.raw_get("skip").unwrap_or(0)));
+					digest.update(format!("//{:?}//{}", file.cha.mtime, t.raw_get("skip").unwrap_or(0)));
 					format!("{:x}", digest.finalize())
 				};
 
