@@ -115,11 +115,28 @@ impl From<FileType> for Cha {
 }
 
 impl Cha {
+	#[inline]
+	pub fn dummy() -> Self { Self { kind: ChaKind::DUMMY, ..Default::default() } }
+
 	#[inline]
 	pub fn with_kind(mut self, kind: ChaKind) -> Self {
 		self.kind |= kind;
 		self
 	}
+
+	#[inline]
+	pub fn hits(self, c: Self) -> bool {
+		self.len == c.len && self.mtime == c.mtime && self.ctime == c.ctime && self.kind == c.kind && {
+			#[cfg(unix)]
+			{
+				self.perm == c.perm
+			}
+			#[cfg(windows)]
+			{
+				true
+			}
+		}
+	}
 }
 
 impl Cha {
