@@ -11,11 +11,14 @@ mod layer;
 mod natsort;
 mod number;
 mod os;
+mod rand;
 mod ro_cell;
-pub mod term;
+pub mod shell;
+mod terminal;
 pub mod theme;
 mod throttle;
 mod time;
+mod translit;
 mod xdg;
 
 pub use chars::*;
@@ -26,10 +29,14 @@ pub use errors::*;
 pub use layer::*;
 pub use natsort::*;
 pub use number::*;
+#[cfg(unix)]
 pub use os::*;
+pub use rand::*;
 pub use ro_cell::*;
+pub use terminal::*;
 pub use throttle::*;
 pub use time::*;
+pub use translit::*;
 pub use xdg::*;
 
 pub fn init() { event::Event::init(); }
